==> wechat-facade-1.0.2-20190117.080111-17-sources.jar: com/bizvane/wechatfacade/models/vo/CreateMiniprgmQRCodeRequestVO.java <==
package com.bizvane.wechatfacade.models.vo;

import java.io.Serializable;

import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;

@ApiModel("创建小程序自定义页面二维码")
public class CreateMiniprgmQRCodeRequestVO implements Serializable {
  
  /**
   * 
   */
  private static final long serialVersionUID = 1L;

  @ApiModelProperty(value = "品牌id", name = "sysBrandId", required = true)
  private Long sysBrandId;
  
  @ApiModelProperty(value = "小程序类型：10-个人中心小程序，20-微商城小程序", name = "miniProgramType", required = true)
  private String miniProgramType;
  
  @ApiModelProperty(value = "页面路径：必须是已经发布的小程序存在的页面（否则报错），例如 pages/index/index, 根路径前不要填加 /,不能携带参数（参数请放在scene字段里），如果不填写这个字段，默认跳主页面", name = "path", required = false, example = "pages/template01/coupon-scancode/main")
  private String path;
  
  @ApiModelProperty(value = "参数：最大32个可见字符，只支持数字，大小写英文以及部分特殊字符：!#$&'()*+,/:;=?@-._~，其它字符请自行编码为合法字符（因不支持%，中文无法使用 urlencode 处理，请使用其他编码方式）", name = "scene", required = true)
  private String scene;

  public Long getSysBrandId() {
    return sysBrandId;
  }

  public void setSysBrandId(Long sysBrandId) {
    this.sysBrandId = sysBrandId;
  }

  public String getMiniProgramType() {
    return miniProgramType;
  }

  public void setMiniProgramType(String miniProgramType) {
    this.miniProgramType = miniProgramType;
  }

  public String getPath() {
    return path;
  }

  public void setPath(String path) {
    this.path = path;
  }

  public String getScene() {
    return scene;
  }

  public void setScene(String scene) {
    this.scene = scene;
  }

  public static long getSerialversionuid() {
    return serialVersionUID;
  }
  
}

==> wechat-facade-2.0.0-20191121.034031-7-sources.jar: com/bizvane/wechatfacade/models/vo/CreateMiniprgmQRCodeRequestVO.java <==
package com.bizvane.wechatfacade.models.vo;

import java.io.Serializable;

import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;

@ApiModel("创建小程序自定义页面二维码")
public class CreateMiniprgmQRCodeRequestVO implements Serializable {
  
  /**
   * 
   */
  private static final long serialVersionUID = 1L;

  @ApiModelProperty(value = "品牌id", name = "sysBrandId", required = true)
  private Long sysBrandId;
  
  @ApiModelProperty(value = "小程序类型：10-个人中心小程序，20-微商城小程序", name = "miniProgramType", required = true)
  private String miniProgramType;
  
  @ApiModelProperty(value = "页面路径：必须是已经发布的小程序存在的页面（否则报错），例如 pages/index/index, 根路径前不要填加 /,不能携带参数（参数请放在scene字段里），如果不填写这个字段，默认跳主页面", name = "path", required = false, example = "pages/template01/coupon-scancode/main")
  private String path;
  
  @ApiModelProperty(value = "参数：最大32个可见字符，只支持数字，大小写英文以及部分特殊字符：!#$&'()*+,/:;=?@-._~，其它字符请自行编码为合法字符（因不支持%，中文无法使用 urlencode 处理，请使用其他编码方式）", name = "scene", required = true)
  private String scene;

  @ApiModelProperty(value = "二维码的宽度，单位 px，最小 280px，最大 1280px", name = "scene", required = true)
  private String width;

  public CreateMiniprgmQRCodeRequestVO() {
  }

  public Long getSysBrandId() {
    return sysBrandId;
  }

  public void setSysBrandId(Long sysBrandId) {
    this.sysBrandId = sysBrandId;
  }

  public String getMiniProgramType() {
    return miniProgramType;
  }

  public void setMiniProgramType(String miniProgramType) {
    this.miniProgramType = miniProgramType;
  }

  public String getPath() {
    return path;
  }

  public void setPath(String path) {
    this.path = path;
  }

  public String getScene() {
    return scene;
  }

  public void setScene(String scene) {
    this.scene = scene;
  }

  public static long getSerialversionuid() {
    return serialVersionUID;
  }

  public String getWidth() {
    return width;
  }

  public void setWidth(String width) {
    this.width = width;
  }
}
